summaryrefslogtreecommitdiff
path: root/abot.py
diff options
context:
space:
mode:
authorjomo <github@jomo.tv>2014-07-10 22:58:47 +0200
committerjomo <github@jomo.tv>2014-07-10 22:58:47 +0200
commit7b742a31524f0d92d60b70279f149e9336af1125 (patch)
treea7802d98b8847baf7b155ac4af3914da63b9d445 /abot.py
parent07f1a169c38a78b4ff579fada1bd913e5e2e5e25 (diff)
more noob matching
Diffstat (limited to 'abot.py')
-rw-r--r--abot.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/abot.py b/abot.py
index 6857ff6..e4d0354 100644
--- a/abot.py
+++ b/abot.py
@@ -5,13 +5,13 @@ rank_regex = "visitor|member|builder|trusted|helper|mod|admin|owner|rank"
faq_regex = [
# ranks
- "(how.*? (get|be(come)?|)|who is|are you).*? (%s)" % rank_regex,
+ "(how.*? (get|be(come)?|)|who is|are you).*? (%s)|who owns.* server" % rank_regex,
# WE
"(can|how|why).*? (have|haz|use|get|doesn|can'?t).*? (WorldEdit|WE|W.E.)",
# clearing plot
- "(why|how).*? (do|can).*?( /?p clear| clear.*? plot)",
- # add someone to a plot
- "how.*? add.*? plot"
+ "((why|how).*? (do|can)|how to).*?( /?p clear| clear.*? plot)",
+ # add someone to a plot, claim plot
+ "how.*? (get|claim|own|add).*? plot"
]
faq_regex = [reg_compile(reg.lower()) for reg in faq_regex]
@@ -27,4 +27,4 @@ def onChat(event):
msg(sender, "&aTake a look at &4&l/faq&a and read through the pages.\n ") # trailing space required
event.setCancelled(True)
log("(hidden) %s: '%s'" % (sender.getName(), message))
- break \ No newline at end of file
+ break